@@ -19,6 +19,8 @@
  */
 
 #include "config.h"
+#include "dh-window.h"
+
 #include <string.h>
 #include <math.h>
 #include <glib/gi18n-lib.h>
@@ -29,7 +31,6 @@
 #include "dh-book-manager.h"
 #include "dh-book.h"
 #include "dh-sidebar.h"
-#include "dh-window.h"
 #include "dh-util.h"
 #include "dh-enum-types.h"
 #include "dh-settings.h"
@@ -340,7 +341,7 @@ zoom_in_cb (GSimpleAction *action,
             GVariant      *parameter,
             gpointer       user_data)
 {
-	DhWindow *window = user_data;
+        DhWindow *window = user_data;
         int zoom_level_idx;
 
         zoom_level_idx = window_get_current_zoom_level_index (window);
@@ -359,7 +360,7 @@ zoom_out_cb (GSimpleAction *action,
              GVariant      *parameter,
              gpointer       user_data)
 {
-	DhWindow *window = user_data;
+        DhWindow *window = user_data;
         int zoom_level_idx;
 
         zoom_level_idx = window_get_current_zoom_level_index (window);
@@ -377,7 +378,7 @@ zoom_default_cb (GSimpleAction *action,
                  GVariant      *parameter,
                  gpointer       user_data)
 {
-	DhWindow *window = user_data;
+        DhWindow *window = user_data;
         WebKitWebView *web_view;
 
         web_view = window_get_active_web_view (window);
@@ -589,7 +590,7 @@ window_configure_event_cb (GtkWidget *window,
         dh_util_window_settings_save (
                 GTK_WINDOW (window),
                 dh_settings_peek_window_settings (priv->settings), TRUE);
-	return FALSE;
+        return FALSE;
 }
 
 static void
@@ -678,8 +679,8 @@ dh_window_dispose (GObject *object)
 
         g_clear_object (&priv->settings);
 
-	/* Chain up to the parent class */
-	G_OBJECT_CLASS (dh_window_parent_class)->dispose (object);
+        /* Chain up to the parent class */
+        G_OBJECT_CLASS (dh_window_parent_class)->dispose (object);
 }
 
 static void
@@ -891,17 +892,19 @@ window_web_view_decide_policy_cb (WebKitWebView           *web_view,
 {
         const char   *uri;
         WebKitNavigationPolicyDecision *navigation_decision;
+        WebKitNavigationAction *navigation_action;
 
         if (type != WEBKIT_POLICY_DECISION_TYPE_NAVIGATION_ACTION)
                 return FALSE;
 
         navigation_decision = WEBKIT_NAVIGATION_POLICY_DECISION (policy_decision);
-        uri = webkit_uri_request_get_uri (webkit_navigation_policy_decision_get_request (navigation_decision));
+        navigation_action = webkit_navigation_policy_decision_get_navigation_action (navigation_decision);
+        uri = webkit_uri_request_get_uri (webkit_navigation_action_get_request (navigation_action));
 
         /* make sure to hide the info bar on page change */
         gtk_widget_hide (window_get_active_info_bar (window));
 
-        if (webkit_navigation_policy_decision_get_mouse_button (navigation_decision) == 2) { /* middle click */
+        if (webkit_navigation_action_get_mouse_button (navigation_action) == 2) { /* middle click */
                 webkit_policy_decision_ignore (policy_decision);
                 g_signal_emit (window, signals[OPEN_LINK], 0, uri, DH_OPEN_LINK_NEW_TAB);
                 return TRUE;
@@ -972,7 +975,7 @@ window_web_view_load_failed_cb (WebKitWebView   *web_view,
         markup = g_strdup_printf ("<b>%s</b>",
                        _("Error opening the requested link."));
         message_label = gtk_label_new (markup);
-        gtk_misc_set_alignment (GTK_MISC (message_label), 0, 0.5);
+        gtk_label_set_xalign (GTK_LABEL (message_label), 0.0);
         gtk_label_set_use_markup (GTK_LABEL (message_label), TRUE);
         content_area = gtk_info_bar_get_content_area (GTK_INFO_BAR (info_bar));
         children = gtk_container_get_children (GTK_CONTAINER (content_area));
@@ -1351,7 +1354,6 @@ window_new_tab_label (DhWindow        *window,
         label = gtk_label_new (str);
         gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
         gtk_widget_set_halign (label, GTK_ALIGN_CENTER);
-        gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
         gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 
         close_button = gedit_close_button_new ();
